@@ -12,8 +12,8 @@ struct User{
 
 fn main_async() -> Result<()>{
     let db = DataBase::new("localhost", 3306, "rust", "root", "");
-    let result = db.get_total_rows("users".to_string(), "".to_string());
-    println!("{:?}", result);   
+    let rows = db.get_list("users".to_string(), "id = 5".to_string(), "10".to_string(), "id ASC".to_string(), "".to_string());
+    println!("{:?}", rows);
     
     Ok(())
 }
